summaryrefslogtreecommitdiff
path: root/tools/slang-test/test-context.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tools/slang-test/test-context.cpp')
-rw-r--r--tools/slang-test/test-context.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/slang-test/test-context.cpp b/tools/slang-test/test-context.cpp
index d5af41a78..3e61287cf 100644
--- a/tools/slang-test/test-context.cpp
+++ b/tools/slang-test/test-context.cpp
@@ -18,8 +18,8 @@ TestContext::TestContext()
/// if we are testing on arm, debug, we may want to increase the connection timeout
#if (SLANG_PROCESSOR_ARM || SLANG_PROCESSOR_ARM_64) && defined(_DEBUG)
- // 5 mins(!). This seems to be the order of time needed for timeout on a CI ARM test system on debug
- connectionTimeOutInMs = 1000 * 60 * 5;
+ // 10 mins(!). This seems to be the order of time needed for timeout on a CI ARM test system on debug
+ connectionTimeOutInMs = 1000 * 60 * 10;
#endif
}